@@ -26,16 +26,12 @@
 
 #include <config.h>
 #include <stdlib.h>
-#include <popt.h>
 
 #define GCONF_ENABLE_INTERNALS
 #include <gconf/gconf.h>
 #include <gconf/gconf-client.h>
-#include <popt.h>
 
-extern struct poptOption gconf_options[];
-
-#include "gnome-i18nP.h"
+#include <glib/gi18n-lib.h>
 
 #include <libgnome/libgnome.h>
 
@@ -61,7 +57,7 @@ gnome_gconf_get_gnome_libs_settings_relative (const gchar *subkey)
         gchar *tmp;
 
         tmp = gconf_escape_key (gnome_program_get_app_id (gnome_program_get()), -1);
-        
+
         dir = g_strconcat("/apps/gnome-settings/",
                           tmp,
                           NULL);
@@ -171,7 +167,7 @@ _gnome_gconf_module_info_get (void)
 		NULL /* instance init */,
 		NULL /* pre_args_parse */,
 		NULL /* post_args_parse */,
-		gconf_options,
+		NULL /* options */,
 		NULL /* init_pass */,
 		NULL /* class_init */,
 		NULL, NULL /* expansions */
